/**
 *  File Name  = axBatchRun.java
 *  Class Name = axBatchRun
 *
 *  Copyright 1999-2004, Etasoft Inc.
 *  All rights are reserved. Reproduction in whole or part is prohibited
 *  without the written consent of the copyright owner.
 *
 *  @author tv.
 *  @date Tuesday, May 4, 2004
 */

//package com.etasoft.trans.runtime;

import com.etasoft.trans.transaction.axInputParameters;
import com.etasoft.trans.transaction.axTransactionRunner;
import com.etasoft.trans.mapgui.axRunEventSinkEditor;
import com.etasoft.trans.mapgui.axRunEventSinkWindow;
import com.etasoft.trans.runtime.axRunEventSink;

/**
 * Batch run a bit more complex example of how to run translator
 * via command line.
 */
public final class axBatchRun implements axRunEventSinkWindow {
    
    boolean m_failed = false;
    
    private axBatchRun() {
                
    }

    /**
     * Report progress.
     */
    public void setProgress(String message, int progress, boolean failed) {
        System.out.println(message);
        m_failed = failed;
    }
    
    /**
     * Report everything that goes to log.
     */
    public void appendToLog(String msg) {
        System.out.println(msg);
    }

    /**
     * Error just happened.
     */
    public void showError(Throwable exp) {
        System.out.println("Error: " + exp.getMessage());
        exp.printStackTrace();
    }
    
    public void setRunThread(Thread thread) {
        
    }
    
    private void run(String[] args) {
        
        System.out.println();
        System.out.println(" Cross Translator Batch processing utility");
        System.out.println(" Copyright (C) 2004-2005 Etasoft Inc.");
        System.out.println("");
        System.out.println();
        
        // get map file name here
        if (args.length < 1) {
            System.out.println("Missing input parameters");
            System.out.println("[map_file_name] [parameter1=value1] [parameter2=value2]");
            System.out.println();
            System.out.println("First parameter is mandatory");
            System.out.println("Pass PRIORITY=MIN for workstation type processing");
            System.out.println();
            return;        
        }            
        
        try {

            String mapFileName = args[0];
            axInputParameters inputParameters = new axInputParameters();
            inputParameters.addOver(args, true);
            
            String priority = inputParameters.getProperty("PRIORITY", "MAX");
            
            // run map
            axTransactionRunner runner = new axTransactionRunner(mapFileName, inputParameters);
            axRunEventSink runEventSink = new axRunEventSinkEditor(this);
            runner.setRunEventSink(runEventSink);

            Thread thread = new Thread(runner);
            if (priority.compareToIgnoreCase("MIN") == 0)
                thread.setPriority(Thread.MIN_PRIORITY);   // set to minimum priority for workstation
            else
                thread.setPriority(Thread.MAX_PRIORITY);
            thread.start();
            
            // wait here for processing thread to finish
            thread.join();  // wait for the thread to finish

            if (m_failed)
                System.out.println("PROCESSING FAILED");
            else
                System.out.println("COMPLETE");
        }
        catch (InterruptedException exp) {
            System.out.println("Translation interrupted.");
        }
        catch (Exception exp2) {
            System.out.println(exp2.getMessage());
        }
    }
    
    public static void main(String[] args) {
        new axBatchRun().run(args);
    }

}
