/**
 *  File Name  = axCmdLineRun2.java
 *  Class Name = axCmdLineRun2
 *
 *  Copyright 1999-2004, Etasoft Inc.
 *  All rights are reserved. Reproduction in whole or part is prohibited
 *  without the written consent of the copyright owner.
 *
 *  @author tv.
 *  @date Tuesday, December 14, 2004
 */

import com.etasoft.trans.transaction.axInputParameters;
import com.etasoft.trans.transaction.axTransactionRunner;

// following lines were added to allow loading and access to map 
import com.etasoft.trans.map.*;


/**
 * Command line runner for map execution via command line.
 * Extended version of original axCmdLineRun class.
 */
public final class axCmdLineRun2 {
    
    private axCmdLineRun2() {
                
    }
    
    private void run(String[] args) {
        
        System.out.println();
        System.out.println(" Cross Translator Command Line processing utility");
        System.out.println(" Copyright (C) 2004-2005 Etasoft Inc.");
        System.out.println("");
        System.out.println();
        
        // get map file name here
        if (args.length < 1) {
            System.out.println("Missing input parameters");
            System.out.println("[map_file_name] [parameter1=value1] [parameter2=value2]");
            System.out.println();
            System.out.println("First parameter is mandatory");
            System.out.println("Pass PRIORITY=MIN for workstation type processing");
            System.out.println();
            return;        
        }            
    
        try {
            String mapFileName = args[0];
            axInputParameters inputParameters = new axInputParameters();
            inputParameters.addOver(args, true);
            
            // ____ block of code below shows how to change map properties dynamically during runtime 
            
            // load map from *.cmp file
            axMap map = axMapFile.loadMap(mapFileName);

            // you can load map from external input stream using alternative method below
            // axMap map = axMapFile.loadMap(InputStream myinputStream);
            
            int index = 327;   // this index is just an example - use your object index 
            // Index property value for the map object we want to find in the loaded map
            //  and it's properties changed just before map execution 
            axMapObject mapObj = map.findById(index); 
            
            // now we can cast mapObj to any map object, like axMapSegment, axMapElement, axMapTable
            // Example 1: we change Tag property for the segment in two lines below
            axMapSegment mapSegm = (axMapSegment) mapObj;   // cast may fail if it is not axMapSegment
            mapSegm.setTag("some_value");   // change Tag property for segment

            // Example 2: we change SQL property for the SQL query in two lines below
            axMapTable mapQuery = (axMapTable) mapObj;  // cast may fail if it is not axMapTable
            mapQuery.setSQL("SELECT same_fields_as_in_map WHERE our_specific_where_clause"); // change SQL
            
            // Example 3: we set input file name in DataPath property
            axMapRoot mapRoot = (axMapRoot) mapObj;     // cast may fail if it is not axMapRoot
            mapRoot.setDataPath("file://C:\\test\\myinput.txt");
            
            // ____ end of changes, run the map

            // run map
            axTransactionRunner runner = new axTransactionRunner(map, mapFileName, 
                inputParameters);

            // next line shows how to pass log file name, if not passed it will default to
            // map file name + ".log" or if present to LOG parameter passed via command line
            runner.setLogWriter("C:\\test\\log.txt", 0, null, true);
            //  or disable logging at all by passing false in parameter 4
            runner.setLogWriter("", 0, null, false);
            
            runner.runMap();            

            System.out.println("COMPLETE");
        }
        catch (InterruptedException exp) {
            System.out.println("Translation interrupted.");
        }
        catch (Throwable exp2) {
            System.out.println("PROCESSING FAILED");
            System.out.println("Error: " + exp2.getMessage());
        }
    }
    
    public static void main(String[] args) {
        new axCmdLineRun2().run(args);
    }

}


